@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -110,6 +110,8 @@ gboolean g_mime_parser_eos (GMimeParser *parser);
 char *g_mime_parser_get_from (GMimeParser *parser);
 
 gint64 g_mime_parser_get_from_offset (GMimeParser *parser);
+gint64 g_mime_parser_get_headers_begin (GMimeParser *parser);
+gint64 g_mime_parser_get_headers_end (GMimeParser *parser);
 
 G_END_DECLS
 
